0.9.9 API documentation: geometric.hpp File Reference

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

Functions
geometric.hpp File Reference

Core features More...

Go to the source code of this file.

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL vec< 3, T, Q > | cross (vec< 3, T, Q > const &x, vec< 3, T, Q > const &y)
| Returns the cross product of x and y. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | distance (vec< L, T, Q > const &p0, vec< L, T, Q > const &p1)
| Returns the distance betwwen p0 and p1, i.e., length(p0 - p1). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | dot (vec< L, T, Q > const &x, vec< L, T, Q > const &y)
| Returns the dot product of x and y, i.e., result = x * y. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | faceforward (vec< L, T, Q > const &N, vec< L, T, Q > const &I, vec< L, T, Q > const &Nref)
| If dot(Nref, I) < 0.0, return N, otherwise, return -N. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL T | length (vec< L, T, Q > const &x)
| Returns the length of x, i.e., sqrt(x * x). More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | normalize (vec< L, T, Q > const &x)
| Returns a vector in the same direction as x but with length of 1. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | reflect (vec< L, T, Q > const &I, vec< L, T, Q > const &N)
| For the incident vector I and surface orientation N, returns the reflection direction : result = I - 2.0 * dot(N, I) * N. More...
template<length_t L, typename T , qualifier Q>
GLM_FUNC_DECL vec< L, T, Q > | refract (vec< L, T, Q > const &I, vec< L, T, Q > const &N, T eta)
| For the incident vector I and surface normal N, and the ratio of indices of refraction eta, return the refraction vector. More...

## Detailed Description

Core features

See also
  GLSL 4.20.8 specification, section 8.5 Geometric Functions

Definition in file geometric.hpp.